from dspygen.rdddy.abstract_aggregate import AbstractAggregate


class ActivityExecutionAggregate(AbstractAggregate):
    """Generated class for ActivityExecutionAggregate, inheriting from AbstractAggregate."""
    