from dspygen.rdddy.abstract_value_object import AbstractValueObject


class VariableValueObject(AbstractValueObject):
    """Generated class for VariableValueObject, inheriting from AbstractValueObject."""
    