from dspygen.rdddy.abstract_value_object import AbstractValueObject


class ProcessIDValueObject(AbstractValueObject):
    """Generated class for ProcessIDValueObject, inheriting from AbstractValueObject."""
    