from dspygen.rdddy.abstract_read_model import AbstractReadModel


class ActivityLogReadModel(AbstractReadModel):
    """Generated class for ActivityLogReadModel, inheriting from AbstractReadModel."""
    