from dspygen.rdddy.abstract_value_object import AbstractValueObject


class ContextValueObject(AbstractValueObject):
    """Generated class for ContextValueObject, inheriting from AbstractValueObject."""
    