from dspygen.rdddy.abstract_command import AbstractCommand


class LoadProcessInstanceCommand(AbstractCommand):
    """Generated class for LoadProcessInstanceCommand, inheriting from AbstractCommand."""
    