from dspygen.rdddy.abstract_read_model import AbstractReadModel


class ProcessSummaryReadModel(AbstractReadModel):
    """Generated class for ProcessSummaryReadModel, inheriting from AbstractReadModel."""
    