from dspygen.rdddy.abstract_read_model import AbstractReadModel


class VariableSnapshotReadModel(AbstractReadModel):
    """Generated class for VariableSnapshotReadModel, inheriting from AbstractReadModel."""
    