from dspygen.rdddy.domain_exception import DomainException


class DataProcessingException(DomainException):
    """Generated class for DataProcessingException, inheriting from DomainException."""
    