from dspygen.rdddy.abstract_aggregate import AbstractAggregate


class ProcessInstanceAggregate(AbstractAggregate):
    """Generated class for ProcessInstanceAggregate, inheriting from AbstractAggregate."""
    