from dspygen.rdddy.abstract_aggregate import AbstractAggregate


class ProcessExecutionAggregate(AbstractAggregate):
    """Generated class for ProcessExecutionAggregate, inheriting from AbstractAggregate."""
    