from dspygen.rdddy.abstract_event import AbstractEvent


class ThirdPartyNotificationEvent(AbstractEvent):
    """Generated class for ThirdPartyNotificationEvent, inheriting from AbstractEvent."""
    