from dspygen.rdddy.abstract_event import AbstractEvent


class SystemMessageDisplayedEvent(AbstractEvent):
    """Generated class for SystemMessageDisplayedEvent, inheriting from AbstractEvent."""
    