from dspygen.rdddy.abstract_value_object import AbstractValueObject


class EntityValueObject(AbstractValueObject):
    """Generated class for EntityValueObject, inheriting from AbstractValueObject."""
    