from dspygen.rdddy.abstract_aggregate import AbstractAggregate


class PartnerInteractionAggregate(AbstractAggregate):
    """Generated class for PartnerInteractionAggregate, inheriting from AbstractAggregate."""
    