from dspygen.rdddy.abstract_read_model import AbstractReadModel


class ContextSnapshotReadModel(AbstractReadModel):
    """Generated class for ContextSnapshotReadModel, inheriting from AbstractReadModel."""
    