from dspygen.rdddy.abstract_task import AbstractTask


class UpdateConversationContextTask(AbstractTask):
    """Generated class for UpdateConversationContextTask, inheriting from AbstractTask."""
    