from dspygen.rdddy.abstract_value_object import AbstractValueObject


class StateValueObject(AbstractValueObject):
    """Generated class for StateValueObject, inheriting from AbstractValueObject."""
    