from dspygen.rdddy.abstract_read_model import AbstractReadModel


class ProcessInstanceDetailsReadModel(AbstractReadModel):
    """Generated class for ProcessInstanceDetailsReadModel, inheriting from AbstractReadModel."""
    