from dspygen.rdddy.abstract_command import AbstractCommand


class SaveProcessInstanceCommand(AbstractCommand):
    """Generated class for SaveProcessInstanceCommand, inheriting from AbstractCommand."""
    