from dspygen.rdddy.abstract_value_object import AbstractValueObject


class PartnerDetailsValueObject(AbstractValueObject):
    """Generated class for PartnerDetailsValueObject, inheriting from AbstractValueObject."""
    