from dspygen.rdddy.abstract_command import AbstractCommand


class ReceiveFromPartnerCommand(AbstractCommand):
    """Generated class for ReceiveFromPartnerCommand, inheriting from AbstractCommand."""
    