from dspygen.rdddy.abstract_value_object import AbstractValueObject


class IntentValueObject(AbstractValueObject):
    """Generated class for IntentValueObject, inheriting from AbstractValueObject."""
    