from dspygen.rdddy.abstract_value_object import AbstractValueObject


class ActivityDetailsValueObject(AbstractValueObject):
    """Generated class for ActivityDetailsValueObject, inheriting from AbstractValueObject."""
    