from dspygen.rdddy.domain_exception import DomainException


class IntentNotFoundException(DomainException):
    """Generated class for IntentNotFoundException, inheriting from DomainException."""
    