from dspygen.rdddy.domain_exception import DomainException


class ExecutionFailureException(DomainException):
    """Generated class for ExecutionFailureException, inheriting from DomainException."""
    