from dspygen.rdddy.domain_exception import DomainException


class EntityRecognitionException(DomainException):
    """Generated class for EntityRecognitionException, inheriting from DomainException."""
    