from dspygen.rdddy.domain_exception import DomainException


class ResponseGenerationException(DomainException):
    """Generated class for ResponseGenerationException, inheriting from DomainException."""
    