from dspygen.rdddy.abstract_value_object import AbstractValueObject


class ResponseValueObject(AbstractValueObject):
    """Generated class for ResponseValueObject, inheriting from AbstractValueObject."""
    